==> compton-conf_0.1.0+20150831.orig.tar.xz: compton-conf-0.1.0+20150831/translations/compton-conf_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru" sourcelanguage="en_US">
<context>
    <name>MainDialog</name>
    <message>
        <location filename="../maindialog.ui" line="14"/>
        <source>Special Effect Settings</source>
        <translation>Настройки эффектов окон</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="24"/>
        <source>Shadow</source>
        <translation>Тень</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="30"/>
        <source>The blur radius for shadows</source>
        <translation>Радиус размытия для тени</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="40"/>
        <source>The left offset for shadows</source>
        <translation>Сдвиг влево для тени</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="54"/>
        <source>The top offset for shadows</source>
        <translation>Сдвиг вверх для тени</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="68"/>
        <source>The translucency for shadows</source>
        <translation>Полупрозрачность для тени</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="75"/>
        <source>Color of shadow</source>
        <translation>Цвет тени</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="89"/>
        <source>Fix some weirdness with ARGB windows</source>
        <translation>Исправить некоторые странности с окнами ARGB</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="92"/>
        <source>Zero the part of the shadow&apos;s mask behind the window</source>
        <translation>Обнулить часть маски тени за окном</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="99"/>
        <source>Don&apos;t draw shadows on DND windows</source>
        <translation>Не рисовать тень на окнах перетаскивания объектов</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="106"/>
        <source>Avoid drawing shadows on dock/panel windows</source>
        <translation>Избегать рисования теней на окнах доков/панелей</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="113"/>
        <source>Enabled client-side shadows on windows</source>
        <translation>Разрешить клиентские тени на окнах</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="120"/>
        <source>Avoid drawing shadow on all shaped windows</source>
        <translation>Избегать рисования теней на всех окнах, которые используют 
расширение X Shape</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="138"/>
        <source>Opacity</source>
        <translation>Непрозрачность</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="147"/>
        <source>The opacity for menus</source>
        <translation>Непрозрачность меню</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="154"/>
        <source>Default opacity of inactive windows</source>
        <translation>Непрозрачность неактивных окон</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="161"/>
        <source>Default opacity for active windows</source>
        <translation>Непрозрачность активных окон</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="168"/>
        <source>Opacity of window titlebars and borders</source>
        <translation>Непрозрачность строки заголовка и границ</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="175"/>
        <source>XRender backend: Step size for alpha pictures
(Increasing it may result in less X resource usage)</source>
        <translation>Сервер XRender: размер шага для прозрачных изображений
(Увеличение его может привести к меньшему использованию
ресурсов сервером X)</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="183"/>
        <source>Dim inactive windows</source>
        <translation>Затенять неактивные окна</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="190"/>
        <source>Do not let dimness adjust based on window opacity</source>
        <translation>Запретить непрозрачности окон влиять на затенение</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="197"/>
        <source>Blur background of transparent windows</source>
        <translation>Размывать фон прозрачного окна</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="204"/>
        <source>Blur background of opaque windows with transparent frames as well</source>
        <translation>Размывать фон непрозрачных окон с прозрачной рамкой</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="211"/>
        <source>Do not let blur radius adjust based on window opacity</source>
        <translation>Запретить непрозрачности окон влиять на радиус размытия</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="279"/>
        <source>Fade</source>
        <translation>Затухание</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="285"/>
        <source>Fade windows during opacity changes</source>
        <translation>Использовать затухание при изменении прозрачности окна</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="292"/>
        <source>The time between steps in a fade in milliseconds</source>
        <translation>Время между шагами изменения прозрачности (мс)</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="299"/>
        <source>Opacity change between steps while fading in</source>
        <translation>Шаг изменения прозрачности во время постепенного
появления окна</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="306"/>
        <source>Opacity change between steps while fading out</source>
        <translation>Шаг изменения прозрачности во время постепенного
исчезновения окна</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="313"/>
        <source>Avoid fade windows in/out when opening/closing</source>
        <translation>Не использовать постепенное появление (исчезновение) окна
при открывании (закрывании)</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="356"/>
        <source>Other</source>
        <translation>Прочее</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="362"/>
        <source>Not implemented yet</source>
        <translation>Пока не реализовано</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="375"/>
        <source>About</source>
        <translation>О программе</translation>
    </message>
    <message>
        <location filename="../maindialog.cpp" line="179"/>
        <source>About ComptonConf</source>
        <translation>О ComptonConf</translation>
    </message>
    <message>
        <location filename="../maindialog.cpp" line="180"/>
        <source>ComptonConf - configuration tool for compton

Copyright (C) 2013
Author: Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
        <translation>ComptonConf - инструмент настройки compton

Copyright (C) 2013
Автор: Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
    </message>
</context>
</TS>

==> compton-conf_0.16.0.orig.tar.xz: compton-conf-0.16.0/translations/compton-conf_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru" sourcelanguage="en_US">
<context>
    <name>MainDialog</name>
    <message>
        <location filename="../maindialog.ui" line="14"/>
        <source>Special Effect Settings</source>
        <translation>Настройки эффектов окон</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="24"/>
        <source>Shadow</source>
        <translation>Тень</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="67"/>
        <source>The blur radius for shadows</source>
        <translation>Радиус размытия для тени</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="77"/>
        <source>The left offset for shadows</source>
        <translation>Сдвиг влево для тени</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="91"/>
        <source>The top offset for shadows</source>
        <translation>Сдвиг вверх для тени</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="105"/>
        <source>The translucency for shadows</source>
        <translation>Полупрозрачность для тени</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="122"/>
        <source>Color of shadow</source>
        <translation>Цвет тени</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="57"/>
        <source>Fix some weirdness with ARGB windows</source>
        <translation>Исправить некоторые странности с окнами ARGB</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="60"/>
        <source>Zero the part of the shadow&apos;s mask behind the window</source>
        <translation>Обнулить часть маски тени за окном</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="50"/>
        <source>Don&apos;t draw shadows on DND windows</source>
        <translation>Не рисовать тень на окнах перетаскивания объектов</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="43"/>
        <source>Avoid drawing shadows on dock/panel windows</source>
        <translation>Избегать рисования теней на окнах доков/панелей</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="36"/>
        <source>Enable client-side shadows on windows</source>
        <translation>Включить отрисовку теней на окнах на стороне клиента</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="136"/>
        <source>Avoid drawing shadow on all shaped windows</source>
        <translation>Избегать рисования теней на всех окнах, которые используют 
расширение X Shape</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="143"/>
        <source>Crop shadows of maximized windows from extended displays</source>
        <translation>Исключить тени развернутых окон с других экранов</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="151"/>
        <source>Opacity</source>
        <translation>Непрозрачность</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="160"/>
        <source>The opacity for menus</source>
        <translation>Непрозрачность меню</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="167"/>
        <source>Default opacity of inactive windows</source>
        <translation>Непрозрачность неактивных окон</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="174"/>
        <source>Default opacity for active windows</source>
        <translation>Непрозрачность активных окон</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="181"/>
        <source>Opacity of window titlebars and borders</source>
        <translation>Непрозрачность строки заголовка и границ</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="188"/>
        <source>XRender backend: Step size for alpha pictures
(Increasing it may result in less X resource usage)</source>
        <translation>Движок XRender: размер шага для прозрачных изображений
(Увеличение может снизить потребление ресурсов X-сервером)</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="196"/>
        <source>Dim inactive windows</source>
        <translation>Затенять неактивные окна</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="203"/>
        <source>Do not let dimness adjust based on window opacity</source>
        <translation>Запретить непрозрачности окон влиять на затенение</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="210"/>
        <source>Blur background of transparent windows</source>
        <translation>Размывать фон прозрачного окна</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="217"/>
        <source>Blur background of opaque windows with transparent frames as well</source>
        <translation>Размывать фон непрозрачных окон с прозрачной рамкой</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="224"/>
        <source>Do not let blur radius adjust based on window opacity</source>
        <translation>Запретить непрозрачности окон влиять на радиус размытия</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="292"/>
        <source>Fade</source>
        <translation>Затухание</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="298"/>
        <source>Fade windows during opacity changes</source>
        <translation>Использовать затухание при изменении прозрачности окна</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="305"/>
        <source>The time between steps in a fade in milliseconds</source>
        <translation>Время между шагами изменения прозрачности (мс)</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="312"/>
        <source>Opacity change between steps while fading in</source>
        <translation>Шаг изменения прозрачности во время постепенного
появления окна</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="319"/>
        <source>Opacity change between steps while fading out</source>
        <translation>Шаг изменения прозрачности во время постепенного
исчезновения окна</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="326"/>
        <source>Avoid fade windows in/out when opening/closing</source>
        <translation>Не использовать постепенное появление (исчезновение) окна
при открывании (закрывании)</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="369"/>
        <source>Other</source>
        <translation>Прочее</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="381"/>
        <source>Rendering backend</source>
        <translation>Графический движок</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="393"/>
        <source>X Render</source>
        <translation>Рендер X.org</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="400"/>
        <source>GLX (OpenGL)</source>
        <translation>GLX (OpenGL)</translation>
    </message>
    <message>
        <location filename="../maindialog.ui" line="416"/>
        <source>About</source>
        <translation>О программе</translation>
    </message>
    <message>
        <location filename="../maindialog.cpp" line="209"/>
        <source>About ComptonConf</source>
        <translation>О ComptonConf</translation>
    </message>
    <message>
        <location filename="../maindialog.cpp" line="210"/>
        <source>ComptonConf - configuration tool for compton

Copyright (C) 2013
Author: Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
        <translation>ComptonConf - инструмент настройки compton

Copyright (C) 2013
Автор: Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
    </message>
</context>
</TS>
